import json
from uuid import UUID
import datetime


class UUIDEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, UUID):
            # if the obj is uuid, we simply return the value of uuid
            return str(obj)

        if isinstance(obj, (datetime.date, datetime.datetime)):
            # return str(obj)
            return obj.isoformat()

        return json.JSONEncoder.default(self, obj)



from pydantic import BaseSettings


class Settings(BaseSettings):
    AWS_REGION: str = 'ap-southeast-1'
    AWS_SNS_KEY: str = None
    AWS_SNS_SECRET: str = None
    AWS_SNS_PATH: str = 'arn:aws:sns:ap-southeast-1:580482583062:'

    class Config:
        case_sensitive = True

        fields = {
            'AWS_REGION': {'env': 'AWS_REGION'},
            'AWS_SNS_KEY': {'env': 'AWS_SNS_KEY'},
            'AWS_SNS__SECRET': {'env': 'AWS_SNS__SECRET'},
            'AWS_SNS_PATH': {'env': 'AWS_SNS_PATH'},
        }


settings = Settings()



import boto3
import json

from .settings import settings
from .json import UUIDEncoder


client = boto3.client(
    'sns',
    region_name=settings.AWS_REGION,
    aws_access_key_id=settings.AWS_SNS_KEY,
    aws_secret_access_key=settings.AWS_SNS_SECRET,
)


def publish(topic, body=None, path=None) -> None:
    message = {
        'body': body,
        'path': path,
    }

    # if settings.PRODUCTION:
    #     segment = xray_recorder.current_segment()
    #     message['trace_id'] = segment.trace_id

    message = json.dumps(message, cls=UUIDEncoder)
    message = json.dumps({"default": message})
    resp = client.publish(
        TopicArn=f'{settings.AWS_SNS_PATH}{topic}',
        Message=message,
        MessageStructure="json",
    )
    print('SNS response:', resp)



import setuptools

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

setuptools.setup(
    name='siametrics-lc-utils',
    version='0.0.2',
    packages=setuptools.find_namespace_packages(include=['siametrics.lc.*']),
    url='',
    license='Apache 2.0',
    author='SSripilaipong',
    author_email='santhapon.s@siametrics.com',
    python_requires='>=3.7',
    description='Siametrics Logistics Core Utils',
    install_requires=requirements,
)
